{% extends "crudbuilder/base.html" %}
{% load crudbuilder %}

{% block main_content %}
<div class="container">
	<h3>{{view.title}}</h3>
	<hr/>
	<table class="table table-bordered table-condensed">
		<thead>
			<tr>
				<th>Crud</th>
				<th>Model</th>
				<th>App</th>
			</tr>
		</thead>
		<tbody>
			{% for key, crud in view.cruds %}
				<tr>
					{% with detail=key|crud_detail %}
						<td><a href="{% url detail.2 %}">{{crud|class_name}}</a></td>
						<td>{{detail.0|title}}</td>
						<td>{{detail.1|title}}</td>
					{% endwith %}
				</tr>
			{% endfor %}
		</tbody>

	</table>
</div>

{% endblock %}