{% extends "crudbuilder/base.html" %}
{% load crudbuilder %}

{% block breadcrumb %}
<ul class="breadcrumb">
    <li><a href="{% url app_label|add:'-'|add:custom_postfix_url|add:'-list' %}">{{pluralized_model_name|title}}</a></li>
    <li class="active">Create {{actual_model_name}}</li>
</ul>
{% endblock %}


{% block main_content %}

<div class='container'>
	<h3>Create {{actual_model_name|title}}</h3>
	<hr/>
	{% include "crudbuilder/widgets/form.html" %}
</div>

{% endblock %}
