<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <!-- The above 3 meta tags *must* come first in the head; any other head content must come *after* these tags -->
    <meta name="description" content="">
    <meta name="author" content="">
    <link rel="icon" href="../../favicon.ico">

    {% block title %}{% endblock %}

    {% load staticfiles %}
    <script src="{% static 'crudbuilder/js/jquery-1.11.3.js' %}"></script>
    <!-- Bootstrap core CSS -->
    <link rel="stylesheet" type="text/css" href="{% static 'crudbuilder/css/bootstrap.min.css' %}">

    {% block css %}{% endblock %}
    <!-- HTML5 shim and Respond.js for IE8 support of HTML5 elements and media queries -->
    <!--[if lt IE 9]>
      <script src="https://oss.maxcdn.com/html5shiv/3.7.2/html5shiv.min.js"></script>
      <script src="https://oss.maxcdn.com/respond/1.4.2/respond.min.js"></script>
    <![endif]-->
  </head>

  <body>
    <nav class="navbar navbar-inverse navbar-fixed-top">
      <div class="container">
        <div class="navbar-header">
          <button type="button" class="navbar-toggle collapsed" data-toggle="collapse" data-target="#navbar" aria-expanded="false" aria-controls="navbar">
            <span class="sr-only">Toggle navigation</span>
            <span class="icon-bar"></span>
            <span class="icon-bar"></span>
            <span class="icon-bar"></span>
          </button>
          <a class="navbar-brand" href="#">{{project_name}}</a>
        </div>
        <div id="navbar" class="collapse navbar-collapse">
          {% if user.is_authenticated %}
          <p class="navbar-text pull-right">Logged in as <a href="/auth/logout/?next=/auth/login/">{{ user.username }}</a></p>
          {% else %}
          <p class="navbar-text pull-right"><a href="/auth/login/">Log in</a></p>
          {% endif %}
        </div><!--/.nav-collapse -->
      </div>
    </nav>

    <div class="container">
      <div class="starter-template">
        </br></br>
        </br></br>
        {% block breadcrumb %}{% endblock %}
        {% block main_content %}{% endblock %}
      </div>
    </div><!-- /.container -->

    <!-- Bootstrap core JavaScript
    ================================================== -->
    <!-- Placed at the end of the document so the pages load faster -->
    {% block js %}{% endblock %}
    <script src="{% static 'crudbuilder/js/bootstrap.min.js' %}"></script>
  </body>
</html>
